==> this.path_1.1.0.tar.gz: this.path/src/symbols.h <==
#ifndef THISPATHSYMBOLS_H
#define THISPATHSYMBOLS_H


#include <R.h>
extern SEXP
    thispathofileSymbol          ,
    thispathfileSymbol           ,
    thispathformsgSymbol         ,
    thispatherrorSymbol          ,
    thispathassocwfileSymbol     ,
    thispathdoneSymbol           ,
    insidesourcewashereSymbol    ,
    thispathnSymbol              ,
    _normalizePathSymbol         ,
    _normalizeAgainstSymbol      ,
    stopSymbol                   ,
    delayedAssignSymbol          ,
    normalizePathSymbol          ,
    winslashSymbol               ,
    mustWorkSymbol               ,
    normalizeURL_1Symbol         ,
    sourceSymbol                 ,
    sys_sourceSymbol             ,
    gui_rstudioSymbol            ,
    debugSourceSymbol            ,
    testthatSymbol               ,
    source_fileSymbol            ,
    testthat_uses_brioSymbol     ,
    knitr_output_dirSymbol       ,
    knitrSymbol                  ,
    knitSymbol                   ,
    this_pathSymbol              ,
    wrap_sourceSymbol            ,
    sys_callSymbol               ,
    sys_frameSymbol              ,
    sys_functionSymbol           ,
    sys_nframeSymbol             ,
    sys_parentSymbol             ,
    sys_parentsSymbol            ,
    ofileSymbol                  ,
    owdSymbol                    ,
    old_dirSymbol                ,
    fileSymbol                   ,
    fileNameSymbol               ,
    pathSymbol                   ,
    inputSymbol                  ,
    missingSymbol                ,
    returnSymbol                 ,
    this_path_toplevelSymbol     ,
    encodeStringSymbol           ,
    na_encodeSymbol              ,
    exprSymbol                   ,
    on_exitSymbol                ,
    External2Symbol              ,
    C_setprseen2Symbol           ,
    thispathtempSymbol           ,
    parent_frameSymbol           ,
    invisibleSymbol              ,
    getConnectionSymbol          ,
    as_environmentSymbol         ,
    oenvirSymbol                 ,
    withArgsSymbol               ,
    thispathhelperSymbol         ,
    GetConnectionSymbol          ,
    GetUnderlyingConnectionSymbol,
    summary_connectionSymbol     ,
    requireNamespaceSymbol       ,
    quietlySymbol                ,
    cSymbol                      ,
    libnameSymbol                ,
    _libPathsSymbol              ;


#endif

==> this.path_1.2.0.tar.gz: this.path/src/symbols.h <==
#ifndef THISPATHSYMBOLS_H
#define THISPATHSYMBOLS_H


#include <R.h>
extern SEXP
    thispathofileSymbol          ,
    thispathfileSymbol           ,
    thispathformsgSymbol         ,
    thispatherrorSymbol          ,
    thispathassocwfileSymbol     ,
    thispathdoneSymbol           ,
    insidesourcewashereSymbol    ,
    thispathnSymbol              ,
    _normalizePathSymbol         ,
    _normalizeAgainstSymbol      ,
    stopSymbol                   ,
    delayedAssignSymbol          ,
    normalizePathSymbol          ,
    winslashSymbol               ,
    mustWorkSymbol               ,
    normalizeURL_1Symbol         ,
    sourceSymbol                 ,
    sys_sourceSymbol             ,
    gui_rstudioSymbol            ,
    init_tools_rstudioSymbol     ,
    tools_rstudioSymbol          ,
    _rs_api_getActiveDocumentContextSymbol,
    _rs_api_getSourceEditorContextSymbol,
    debugSourceSymbol            ,
    testthatSymbol               ,
    source_fileSymbol            ,
    testthat_uses_brioSymbol     ,
    knitr_output_dirSymbol       ,
    knitrSymbol                  ,
    knitSymbol                   ,
    wrap_sourceSymbol            ,
    sys_callSymbol               ,
    sys_frameSymbol              ,
    sys_functionSymbol           ,
    sys_nframeSymbol             ,
    sys_parentSymbol             ,
    sys_parentsSymbol            ,
    ofileSymbol                  ,
    owdSymbol                    ,
    old_dirSymbol                ,
    fileSymbol                   ,
    fileNameSymbol               ,
    pathSymbol                   ,
    inputSymbol                  ,
    missingSymbol                ,
    returnSymbol                 ,
    this_path_toplevelSymbol     ,
    encodeStringSymbol           ,
    na_encodeSymbol              ,
    exprSymbol                   ,
    on_exitSymbol                ,
    External2Symbol              ,
    C_setprseen2Symbol           ,
    thispathtempSymbol           ,
    parent_frameSymbol           ,
    invisibleSymbol              ,
    getConnectionSymbol          ,
    as_environmentSymbol         ,
    oenvirSymbol                 ,
    withArgsSymbol               ,
    thispathhelperSymbol         ,
    GetConnectionSymbol          ,
    GetUnderlyingConnectionSymbol,
    summary_connectionSymbol     ,
    require_this_path_helperSymbol,
    _asArgsSymbol                ,
    commandArgsSymbol            ,
    maybe_in_shellSymbol         ,
    _packageName                 ;


#endif
